@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2007-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2007-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -16,7 +16,7 @@
  *
  * @author    Michael J. Rubinsky <mrubinsk@horde.org>
  * @category  Horde
- * @copyright 2007-2016 Horde LLC
+ * @copyright 2007-2017 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL-2.1
  * @package   Image
  */
@@ -47,12 +47,12 @@ class Horde_Image_Effect_Im_DropShadow extends Horde_Image_Effect
     {
         $size = $this->_image->getDimensions();
         $this->_image->addPostSrcOperation(
-            '\( +clone -background black -shadow 80x' . $this->_params['fade']
-            . '+' . $this->_params['distance']
-            . '+' . $this->_params['distance']
-            . ' \) +swap -background none -flatten +repage -bordercolor '
-            . $this->_params['background']
-            . ' -border ' . $this->_params['padding']
+            '\( +clone -background black -shadow 80x' . (integer)$this->_params['fade']
+            . '+' . (integer)$this->_params['distance']
+            . '+' . (integer)$this->_params['distance']
+            . ' \) +swap -background ' . escapeshellarg($this->_params['background']) . ' -flatten +repage -bordercolor '
+            . escapeshellarg($this->_params['background'])
+            . ' -border ' . (integer)$this->_params['padding']
         );
         $this->_image->clearGeometry();
     }
