@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2007-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2007-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -16,7 +16,7 @@
  *
  * @author    Michael J. Rubinsky <mrubinsk@horde.org>
  * @category  Horde
- * @copyright 2007-2016 Horde LLC
+ * @copyright 2007-2017 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL-2.1
  * @package   Image
  */
@@ -44,11 +44,11 @@ class Horde_Image_Effect_Im_RoundCorners extends Horde_Image_Effect
         $dimensions = $this->_image->getDimensions();
         $height = $dimensions['height'];
         $width = $dimensions['width'];
-        $round = $this->_params['radius'];
-
+        $round = (integer)$this->_params['radius'];
+        $background = escapeshellarg($this->_params['background']);
         $this->_image->addOperation(
-            "-size {$width}x{$height} xc:{$this->_params['background']} "
-            . "-fill {$this->_params['background']} -draw \"matte 0,0 reset\" -tile"
+            "-size {$width}x{$height} xc:$background "
+            . "-fill $background -draw \"matte 0,0 reset\" -tile"
         );
 
         $this->_image->roundedRectangle(
